@@ -98,6 +98,7 @@ get_otps_from_encrypted_backup (const gchar          *path,
         g_free (key_nonce);
         g_free (key_tag);
         gcry_free (keybuf);
+        json_decref (json);
         return NULL;
     }
 
@@ -108,6 +109,7 @@ get_otps_from_encrypted_backup (const gchar          *path,
         g_free (key_nonce);
         g_free (key_tag);
         gcry_free (keybuf);
+        json_decref (json);
         return NULL;
     }
 
@@ -121,6 +123,7 @@ get_otps_from_encrypted_backup (const gchar          *path,
         gcry_free (master_key);
         gcry_free (keybuf);
         gcry_cipher_close (hd);
+        json_decref (json);
         return NULL;
     }
     gpg_error_t gpg_err = gcry_cipher_checktag (hd, key_tag, TAG_SIZE);
@@ -133,6 +136,7 @@ get_otps_from_encrypted_backup (const gchar          *path,
         gcry_free (master_key);
         gcry_free (keybuf);
         gcry_cipher_close (hd);
+        json_decref (json);
         return NULL;
     }
 
@@ -151,20 +155,24 @@ get_otps_from_encrypted_backup (const gchar          *path,
         g_free (tag);
         g_free (nonce);
         gcry_free (master_key);
+        json_decref (json);
         return NULL;
     }
 
     gsize out_len;
-    guchar *b64decoded_db = g_base64_decode_secure (json_string_value (json_object_get (json, "db")), &out_len);
+    guchar *b64decoded_db = g_base64_decode (json_string_value (json_object_get (json, "db")), &out_len);
     if (out_len > max_file_size) {
         g_set_error (err, file_too_big_gquark (), FILE_TOO_BIG, "File is too big");
         g_free (tag);
         g_free (nonce);
         gcry_free (master_key);
-        gcry_free (b64decoded_db);
+        g_free (b64decoded_db);
         gcry_cipher_close (hd);
+        json_decref (json);
         return NULL;
     }
+    // we no longer need the json object, so we can free up some secure memory
+    json_decref (json);
 
     gchar *decrypted_db = gcry_calloc_secure (out_len, 1);
     gpg_err = gcry_cipher_decrypt (hd, decrypted_db, out_len, b64decoded_db, out_len);
@@ -175,24 +183,30 @@ get_otps_from_encrypted_backup (const gchar          *path,
     if (gpg_err != 0) {
         g_set_error (err, bad_tag_gquark (), BAD_TAG_ERRCODE, "Invalid TAG (database). Either the password is wrong or the file is corrupted.");
         clean_and_exit:
+        g_free (b64decoded_db);
         g_free (nonce);
         g_free (tag);
         gcry_free (master_key);
         gcry_free (decrypted_db);
-        gcry_free (b64decoded_db);
         gcry_cipher_close (hd);
         return NULL;
     }
 
+    g_free (b64decoded_db);
     g_free (nonce);
     g_free (tag);
     gcry_cipher_close (hd);
     gcry_free (master_key);
-    gcry_free (b64decoded_db);
 
-    GSList *otps = parse_json_data (decrypted_db, err);
+    // we remove the icon field (and the icon_mime while at it too) because it uses lots of secure memory for nothing
+    GRegex *regex = g_regex_new (".*\"icon\":(\\s)*\".*\",\\n|.*\"icon_mime\":(\\s)*\".*\",\\n", G_REGEX_MULTILINE, 0, NULL);
+    gchar *cleaned_db = secure_strdup (g_regex_replace (regex, decrypted_db, -1, 0, "", 0, NULL));
+    g_regex_unref (regex);
     gcry_free (decrypted_db);
 
+    GSList *otps = parse_json_data (cleaned_db, err);
+    gcry_free (cleaned_db);
+
     return otps;
 }
 
@@ -372,20 +386,36 @@ export_aegis (const gchar   *export_path,
         gcry_cipher_close (hd);
     }
 
-    FILE *fp = fopen (export_path, "w");
-    if (fp == NULL) {
-        g_set_error (&err, generic_error_gquark (), GENERIC_ERRCODE, "couldn't create the file object");
-    } else {
-        if (json_dumpf (root, fp, JSON_COMPACT) == -1) {
-            g_set_error (&err, generic_error_gquark (), GENERIC_ERRCODE, "couldn't dump json data to file");
+    GFile *out_gfile = g_file_new_for_path (export_path);
+    GFileOutputStream *out_stream = g_file_replace (out_gfile, NULL, FALSE, G_FILE_CREATE_REPLACE_DESTINATION | G_FILE_CREATE_PRIVATE, NULL, &err);
+    if (err == NULL) {
+        gsize jbuf_size = json_dumpb (root, NULL, 0, 0);
+        if (jbuf_size == 0) {
+            goto cleanup_and_exit;
         }
-        fclose (fp);
+        gchar *jbuf = g_malloc0 (jbuf_size);
+        if (json_dumpb (root, jbuf, jbuf_size, JSON_COMPACT) == -1) {
+            g_set_error (&err, generic_error_gquark (), GENERIC_ERRCODE, "couldn't dump json data to buffer");
+            g_free (jbuf);
+            goto cleanup_and_exit;
+        }
+        if (g_output_stream_write (G_OUTPUT_STREAM(out_stream), jbuf, jbuf_size, NULL, &err) == -1) {
+            g_set_error (&err, generic_error_gquark (), GENERIC_ERRCODE, "couldn't dump json data to file");
+            g_free (jbuf);
+            goto cleanup_and_exit;
+        }
+        g_free (jbuf);
+    } else {
+        g_set_error (&err, generic_error_gquark (), GENERIC_ERRCODE, "couldn't create the file object");
     }
 
+    cleanup_and_exit:
     json_array_clear (array);
     json_decref (aegis_db_obj);
     json_decref (aegis_header_obj);
     json_decref (root);
+    g_object_unref (out_stream);
+    g_object_unref (out_gfile);
 
     return (err != NULL ? g_strdup (err->message) : NULL);
 }
