@@ -4,6 +4,7 @@
 #include <time.h>
 #include "../file-size.h"
 #include "../parse-uri.h"
+#include "../gquarks.h"
 
 
 GSList *
@@ -38,18 +39,23 @@ export_freeotpplus (const gchar *export_path,
     json_t *db_obj;
     gsize index;
 
-    FILE *fp = fopen (export_path, "w");
-    if (fp == NULL) {
-        return g_strdup ("couldn't create the file object");
+    GError *err = NULL;
+    GFile *out_gfile = g_file_new_for_path (export_path);
+    GFileOutputStream *out_stream = g_file_replace (out_gfile, NULL, FALSE, G_FILE_CREATE_REPLACE_DESTINATION | G_FILE_CREATE_PRIVATE, NULL, &err);
+    if (err == NULL) {
+        json_array_foreach (json_db_data, index, db_obj) {
+            gchar *uri = get_otpauth_uri (NULL, db_obj);
+            if (g_output_stream_write (G_OUTPUT_STREAM(out_stream), uri, g_utf8_strlen (uri, -1) + 1, NULL, &err) == -1) {
+                g_set_error (&err, generic_error_gquark (), GENERIC_ERRCODE, "couldn't dump json data to file");
+            }
+            g_free (uri);
+        }
+    } else {
+        g_set_error (&err, generic_error_gquark (), GENERIC_ERRCODE, "couldn't create the file object");
     }
 
-    json_array_foreach (json_db_data, index, db_obj) {
-        gchar *uri = get_otpauth_uri (NULL, db_obj);
-        fwrite (uri, strlen (uri), 1, fp);
-        g_free (uri);
-    }
+    g_object_unref (out_stream);
+    g_object_unref (out_gfile);
 
-    fclose (fp);
-
-    return NULL;
+    return (err != NULL ? g_strdup (err->message) : NULL);
 }
